@@ -6,7 +6,7 @@ use crate::{DebugPls, Formatter};
 /// # Examples
 ///
 /// ```rust
-/// use dbg_pls::{debug, DebugPls, Formatter};
+/// use dbg_pls::{pretty, DebugPls, Formatter};
 /// use std::collections::BTreeSet;
 ///
 /// struct Foo(BTreeSet<String>);
@@ -21,7 +21,7 @@ use crate::{DebugPls, Formatter};
 ///     "World".to_string(),
 /// ]));
 /// assert_eq!(
-///     format!("{}", debug(&value)),
+///     format!("{}", pretty(&value)),
 /// "{
 ///     \"Hello\";
 ///     \"World\"
@@ -45,6 +45,7 @@ impl<'a> DebugSet<'a> {
     }
 
     /// Adds the entry to the set output.
+    #[must_use]
     pub fn entry(mut self, value: &dyn DebugPls) -> Self {
         let expr = Formatter::process(value);
         self.set
@@ -54,6 +55,7 @@ impl<'a> DebugSet<'a> {
     }
 
     /// Adds all the entries to the set output.
+    #[must_use]
     pub fn entries<V, I>(self, entries: I) -> Self
     where
         V: DebugPls,
